import java.io.*;
import java.awt.*;
import java.awt.event.*; 
import javax.swing.*; 
import javax.swing.event.*; 

public class Editor extends JFrame { 

	public Editor(String asignatura) {
		setTitle("Proyectos personales " + asignatura);
		setSize(400, 700);
		setLocation(10, 10);
		gui = new EditorGUI(asignatura);

		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				System.exit(0); 
			} 
		} );
 
		getContentPane().add(gui);
		setVisible(true); 
	} 

	EditorGUI gui;
}

class EditorGUI extends JPanel {

	public EditorGUI(String asignatura) {
		curso = new Organizador();
		indiceProyecto = 0;
		curso.setAsignatura(asignatura);
		curso.setListadoAlumnos(asignatura + ".txt");
		curso.setProyectos("proyectos" + asignatura+ ".txt");

		setLayout(new FlowLayout(FlowLayout.LEFT));

		add(eAsignatura);
		add(eProyecto);
		add(eAlumno);
		add(e01);
		add(fNombreProyecto);
		add(e02);
		add(aDescripcionProblema);
		add(e03);
		add(aSolucionInicial);
		add(e04);
		add(aAlumnosFaltantes);
		add(bAnterior);
		add(bSiguiente);
		add(bEliminar);
		add(bMvAtras);
		add(bMvAdelante);
		add(bModificar);
		add(bGuardar);
		add(bCrearHTML);
		add(bFinalizar);

		bAnterior.addActionListener(alAnterior);
		bSiguiente.addActionListener(alSiguiente);
		bEliminar.addActionListener(alEliminar);
		bMvAtras.addActionListener(alMvAtras);
		bMvAdelante.addActionListener(alMvAdelante);
		bModificar.addActionListener(alModificar);
		bFinalizar.addActionListener(alFinalizar);
		bCrearHTML.addActionListener(alCrearHTML);
		bGuardar.addActionListener(alGuardar);

		eAsignatura.setText(asignatura + utilString.sps);
		eProyecto.setText("Proyecto 1 de " + curso.getNumeroProyectos() + utilString.sps);
		eAlumno.setText(
			curso.getNombreAlumnoEnProyectoEnIndice(0) + utilString.sps);
		fNombreProyecto.setText(
			curso.getNombreProyectoEnProyectoEnIndice(0));
		aDescripcionProblema.setText(
			utilString.reemplazar(
				curso.getDescripcionProblemaEnProyectoEnIndice(0),
				"<br>", "\n"));
		aSolucionInicial.setText(
			utilString.reemplazar(
				curso.getSolucionInicialEnProyectoEnIndice(0),
				"<br>", "\n"));
		aAlumnosFaltantes.setText(curso.getAlumnosFaltantes());
		e01.setText("Nombre del Proyecto" + utilString.sps);
		e02.setText("Descripcion del problema" + utilString.sps);
		e03.setText("Idea inicial para la solucion" + utilString.sps);
		e04.setText("Alumnos que no han inscrito proyecto" + utilString.sps);

		aDescripcionProblema.setLineWrap(true);
		aDescripcionProblema.setWrapStyleWord(true);
		aSolucionInicial.setLineWrap(true);
		aSolucionInicial.setWrapStyleWord(true);
	}

	public void mostrarProyecto(int indice) {

		eProyecto.setText("Proyecto " + Integer.toString(indice + 1) + " de " + curso.getNumeroProyectos() + utilString.sps);
		eAlumno.setText(
			curso.getNombreAlumnoEnProyectoEnIndice(indice) + utilString.sps);
		fNombreProyecto.setText(
			curso.getNombreProyectoEnProyectoEnIndice(indice));
		aDescripcionProblema.setText(
			utilString.reemplazar(
				curso.getDescripcionProblemaEnProyectoEnIndice(indice),
				"<br>", "\n"));
		aSolucionInicial.setText(
			utilString.reemplazar(
				curso.getSolucionInicialEnProyectoEnIndice(indice),
				"<br>", "\n"));
		aAlumnosFaltantes.setText(curso.getAlumnosFaltantes());
	}

	public void siguiente() {
		if(indiceProyecto < (curso.getNumeroProyectos() - 1)) {
			indiceProyecto++;
			mostrarProyecto(indiceProyecto);
		}
	}

	public void anterior() {
		if(indiceProyecto > 0) {
			indiceProyecto--;
			mostrarProyecto(indiceProyecto);
		}
	}

	public void eliminar() {
		if(curso.getNumeroProyectos() > 1) {
			curso.eliminarProyectoEnIndice(indiceProyecto);
			indiceProyecto = 0;
			mostrarProyecto(indiceProyecto);
		}
	}

	public void modificar() {
		Proyecto proyecto = new Proyecto();
		proyecto.setNombreAlumno(curso.getNombreAlumnoEnProyectoEnIndice(indiceProyecto));
		proyecto.setNombreProyecto(fNombreProyecto.getText());
		proyecto.setDescripcionProblema(
			utilString.reemplazar(aDescripcionProblema.getText(), "\n", "<br>"));
		proyecto.setSolucionInicial(
			utilString.reemplazar(aSolucionInicial.getText(), "\n", "<br>"));

		curso.eliminarProyectoEnIndice(indiceProyecto);
		curso.insertarProyectoEnIndice(proyecto, indiceProyecto);
		mostrarProyecto(indiceProyecto);
	}

	public void mvAdelante() {
		indiceProyecto = curso.avanzaUnLugarProyectoEnIndice(indiceProyecto);
		mostrarProyecto(indiceProyecto);
	}

	public void mvAtras() {
		indiceProyecto = curso.retrocedeUnLugarProyectoEnIndice(indiceProyecto);
		mostrarProyecto(indiceProyecto);
	}

	public void guardar() {
		try {
			PrintWriter pw = new PrintWriter(
				new BufferedWriter(new FileWriter(
					"proyectos" + curso.getAsignatura() + ".txt", false)));

			pw.println(curso.getProyectos());
			pw.close();
		} catch(Throwable excepcion) {
			System.out.println(excepcion);
		}
	}

	public void crearHTML() {
		try {
			PrintWriter pw = new PrintWriter(
				new BufferedWriter(new FileWriter(
					"proyectos" + curso.getAsignatura() + ".html", false)));

			pw.println(curso.toStringHTML("pagina.html", "tabla.html"));
			pw.close();
		} catch(Throwable excepcion) {
			System.out.println(excepcion);
		}
	}

	private void finalizar(){
		System.out.println("Hasta luego.");
		System.exit(0);
	}

	// Las etiquetas.
	private JLabel eAsignatura = new JLabel();
	private JLabel eAlumno = new JLabel();
	private JLabel eProyecto = new JLabel();
	private JLabel e01 = new JLabel();
	private JLabel e02 = new JLabel();
	private JLabel e03 = new JLabel();
	private JLabel e04 = new JLabel();
	// El campo de texto.
	private JTextField fNombreProyecto = new JTextField(30);
	// Las areas de texto.
	private JTextArea aDescripcionProblema = new JTextArea(10, 30);
	private JTextArea aSolucionInicial = new JTextArea(10, 30);
	private JTextArea aAlumnosFaltantes = new JTextArea(5, 30);
	// Los botones.
	private JButton bAnterior = new JButton("<< Ver Anterior");
	private JButton bSiguiente = new JButton("Ver Siguiente >>");
	private JButton bEliminar = new JButton("Eliminar Proyecto");
	private JButton bMvAtras = new JButton("<< Mover Atras");
	private JButton bMvAdelante = new JButton("Mover Adelante >>");
	private JButton bModificar = new JButton("Modificar");
	private JButton bGuardar = new JButton("Guardar Cambios");
	private JButton bCrearHTML = new JButton("Crear HTML");
	private JButton bFinalizar = new JButton("Finalizar");
	// Los action listener.
	private ActionListener alAnterior = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			anterior();
	} };
	private ActionListener alSiguiente = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			siguiente();
	} };
	private ActionListener alFinalizar = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			finalizar();
	} };
	private ActionListener alEliminar = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			eliminar();
	} };
	private ActionListener alMvAdelante = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			mvAdelante();
	} };
	private ActionListener alMvAtras = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			mvAtras();
	} };
	private ActionListener alModificar = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			modificar();
	} };
	private ActionListener alGuardar = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			guardar();
	} };
	private ActionListener alCrearHTML = new ActionListener() {
		public void actionPerformed(ActionEvent e){
			crearHTML();
	} };

	private Organizador curso;
	private int indiceProyecto;
}